==> rheolef_6.7.orig.tar.gz: rheolef-6.7/doc/pexamples/neumann-laplace.sh <==
#!/bin/sh
#
# This file is part of Rheolef.
#
# Copyright (C) 2000-2009 Pierre Saramito 
#
# Rheolef is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Rheolef is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Rheolef; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# -------------------------------------------------------------------------
SRCDIR=${SRCDIR-"."}
TOP_SRCDIR=${TOP_SRCDIR-"../.."}
DATADIR="${TOP_SRCDIR}/nfem/ptst"
NPROC_MAX=${NPROC_MAX-"3"}
. "${TOP_SRCDIR}/config/loop_mpirun.sh"

status=0

eps="1e-7"
# geo                   err_P1  err_P2  err_P3
L="
line-bdry-v2            9e-4	$eps	$eps
carre-bamg-v2           2e-3	$eps	$eps
carre-bamg-q-dom-v2     5e-4	$eps	$eps
carre-tq-10-dom-v2      2e-3	$eps	$eps
cube-dom-v2             2e-2	$eps	$eps
cube-H-6-dom-v2         3e-3	$eps	$eps
cube-P-5-dom-v2         7e-3	$eps	$eps
my_cube_PH-5-v2         8e-3	$eps	$eps
my_cube_TP-5-v2         8e-3	$eps	$eps
my_cube_TPH-5-v2        7e-3	$eps	$eps
"
while test "$L" != ""; do
  geo=`echo $L | awk '{print $1}'`
  L=`echo $L | awk '{for (i=2; i <= NF; i++) print $i}'`
  for Pk in P1 P2 P3; do
    err=`echo $L | awk '{print $1}'`
    L=`echo $L | awk '{for (i=2; i <= NF; i++) print $i}'`
    loop_mpirun "./neumann-laplace $DATADIR/$geo $Pk 2>/dev/null | RHEOPATH=$DATADIR ./neumann-laplace-check $err 2>/dev/null >/dev/null"
    if test $? -ne 0; then status=1; fi
  done
done

exit $status

==> rheolef_7.0.orig.tar.gz: rheolef-7.0/doc/pexamples/neumann-laplace.sh <==
#!/bin/sh
#
# This file is part of Rheolef.
#
# Copyright (C) 2000-2009 Pierre Saramito 
#
# Rheolef is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Rheolef is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Rheolef; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# -------------------------------------------------------------------------
TOP_SRCDIR=${TOP_SRCDIR-"../../../rheolef"}
SRCDIR=${SRCDIR-"$TOP_SRCDIR/doc/pexamples"}
DATADIR="${TOP_SRCDIR}/nfem/ptst"
NPROC_MAX=${NPROC_MAX-"3"}
. "${TOP_SRCDIR}/config/loop_mpirun.sh"

status=0

eps="1e-7"
# geo                   err_P1  err_P2  err_P3
L="
line-bdry-v2            9e-4	$eps	$eps
carre-bamg-v2           2e-3	$eps	$eps
carre-bamg-q-dom-v2     5e-4	$eps	$eps
carre-tq-10-dom-v2      2e-3	$eps	$eps
cube-dom-v2             2e-2	$eps	$eps
cube-H-6-dom-v2         3e-3	$eps	$eps
cube-P-5-dom-v2         7e-3	$eps	$eps
my_cube_PH-5-v2         8e-3	$eps	$eps
my_cube_TP-5-v2         8e-3	$eps	$eps
my_cube_TPH-5-v2        7e-3	$eps	$eps
"
while test "$L" != ""; do
  geo=`echo $L | awk '{print $1}'`
  L=`echo $L | awk '{for (i=2; i <= NF; i++) print $i}'`
  for Pk in P1 P2 P3; do
    err=`echo $L | awk '{print $1}'`
    L=`echo $L | awk '{for (i=2; i <= NF; i++) print $i}'`
    loop_mpirun "./neumann-laplace $DATADIR/$geo $Pk 2>/dev/null | RHEOPATH=$DATADIR ./neumann-laplace-check $err 2>/dev/null >/dev/null"
    if test $? -ne 0; then status=1; fi
  done
done

exit $status
